==> fetch.php?media=uls%3Auls_update-1.9.5.tgz: update/von_1.9.2/sql/ueberwachungspausen_trigger.sql <==
set @@character_set_client = 'utf8';

delimiter //

drop trigger if exists ueberwachungspausen_au//
create trigger ueberwachungspausen_au after update on ueberwachungspausen
  for each row 
begin
  insert into changeprot
    (domainID, accessID, changedtable, tableID, userID, username, action,
     classes, server, section, teststep, details, unit, newvalues)
  select NEW.verfahrenID, NEW.accessID, 'ueberwachungspausen', NEW.ID,
    coalesce(@userid,0), coalesce(@username,@srvname,'SYSTEM'), 'update',
    showreg(NEW.classes, NEW.classes_v), showreg(NEW.server, NEW.server_v), showreg(NEW.section, NEW.section_v),
    showreg(NEW.teststep, NEW.teststep_v), showreg(NEW.details, NEW.details_v),
    showreg(NEW.einheit, NEW.einheit_v),
    concat('datefrom=', NEW.datumvon, '\ndateto=', NEW.datumbis,
           if(NEW.weekdays = '0,1,2,3,4,5,6', '', concat('\nweekdays=', weekdaynames(NEW.weekdays))),
           if(NEW.mdaystart = 0 AND NEW.mdayend = 32, '',
              concat('\nmonthdayfrom=', NEW.mdaystart, '\nmonthdayto=', NEW.mdayend)),
           if(NEW.zeitvon = '00:00:00' AND NEW.zeitbis = '23:59:59', '',
              concat('\ntimefrom=', NEW.zeitvon, '\ntimeto=', coalesce(@suspensiontimeto,NEW.zeitbis))),
           '\nremark=', quotenl(NEW.bemerkung))
  from dual
  where NEW.nextdayID = 0 and NEW.TS != OLD.TS;
end//


drop trigger if exists ueberwachungspausen_ai//
create trigger ueberwachungspausen_ai after insert on ueberwachungspausen
  for each row 
begin
  insert into changeprot
    (domainID, accessID, changedtable, tableID, userID, username, action,
     classes, server, section, teststep, details, unit, newvalues)
  select NEW.verfahrenID, NEW.accessID, 'ueberwachungspausen', NEW.ID,
    coalesce(@userid,0), coalesce(@username,@srvname,'SYSTEM'), 'insert',
    showreg(NEW.classes, NEW.classes_v), showreg(NEW.server, NEW.server_v), showreg(NEW.section, NEW.section_v),
    showreg(NEW.teststep, NEW.teststep_v), showreg(NEW.details, NEW.details_v),
    showreg(NEW.einheit, NEW.einheit_v),
    concat('datefrom=', NEW.datumvon, '\ndateto=', NEW.datumbis,
           if(NEW.weekdays = '0,1,2,3,4,5,6', '', concat('\nweekdays=', weekdaynames(NEW.weekdays))),
           if(NEW.mdaystart = 0 AND NEW.mdayend = 32, '',
              concat('\nmonthdayfrom=', NEW.mdaystart, '\nmonthdayto=', NEW.mdayend)),
           if(NEW.zeitvon = '00:00:00' AND NEW.zeitbis = '23:59:59', '',
              concat('\ntimefrom=', NEW.zeitvon, '\ntimeto=', coalesce(@suspensiontimeto,NEW.zeitbis))),
           '\nremark=', quotenl(NEW.bemerkung))
  from dual
  where NEW.nextdayID = 0;
end//


drop trigger if exists ueberwachungspausen_bd//
create trigger ueberwachungspausen_bd before delete on ueberwachungspausen
  for each row 
begin
  insert into changeprot
    (domainID, accessID, changedtable, tableID, userID, username, action,
     classes, server, section, teststep, details, unit, newvalues)
  select OLD.verfahrenID, OLD.accessID, 'ueberwachungspausen', OLD.ID,
    coalesce(@userid,0), coalesce(@username,@srvname,'SYSTEM'), 'delete',
    showreg(OLD.classes, OLD.classes_v), showreg(OLD.server, OLD.server_v), showreg(OLD.section, OLD.section_v),
    showreg(OLD.teststep, OLD.teststep_v), showreg(OLD.details, OLD.details_v),
    showreg(OLD.einheit, OLD.einheit_v),
    coalesce(if(OLD.bemerkung = @suspensionremark OR OLD.serversetID > 0, '', concat('remark=', quotenl(@suspensionremark))),'')
    from dual
    where OLD.nextdayID = 0;
end//

delimiter ;

==> fetch.php?media=uls%3Auls_update-1.9.6.tgz: update/von_1.9.5/sql/ueberwachungspausen_trigger.sql <==
set @@character_set_client = 'utf8';

delimiter //

drop trigger if exists ueberwachungspausen_au//
create trigger ueberwachungspausen_au after update on ueberwachungspausen
  for each row 
begin
  insert into changeprot
    (domainID, accessID, changedtable, tableID, userID, username, action,
     classes, server, section, teststep, details, unit, newvalues)
  select NEW.verfahrenID, NEW.accessID, 'ueberwachungspausen', NEW.ID,
    coalesce(@userid,0), coalesce(@username,@srvname,'SYSTEM'), 'update',
    showreg(NEW.classes, NEW.classes_v), showreg(NEW.server, NEW.server_v), showreg(NEW.section, NEW.section_v),
    showreg(NEW.teststep, NEW.teststep_v), showreg(NEW.details, NEW.details_v),
    showreg(NEW.einheit, NEW.einheit_v),
    concat('datefrom=', NEW.datumvon,
           '\ndateto=', NEW.datumbis,
           if(NEW.weekdays = '0,1,2,3,4,5,6', '', concat('\nweekdays=', weekdaynames(NEW.weekdays))),
           if(NEW.mdays = '', '', concat('\nmdays=', getrange(NEW.mdays))),
           if(NEW.zeitvon = '00:00:00' AND NEW.zeitbis = '23:59:59', '',
              concat('\ntimefrom=', NEW.zeitvon, '\ntimeto=', coalesce(@suspensiontimeto,NEW.zeitbis))),
           '\nremark=', REPLACE(REPLACE(NEW.bemerkung, '\\', '\\\\'), '\n', '\\n'))
  from ueberwachungspausen
  where ueberwachungspausen.ID = NEW.ID and NEW.nextdayID = 0 and NEW.TS = ueberwachungspausen.TS;
end//


drop trigger if exists ueberwachungspausen_ai//
create trigger ueberwachungspausen_ai after insert on ueberwachungspausen
  for each row 
begin
  insert into changeprot
    (domainID, accessID, changedtable, tableID, userID, username, action,
     classes, server, section, teststep, details, unit, newvalues)
  select NEW.verfahrenID, NEW.accessID, 'ueberwachungspausen', NEW.ID,
    coalesce(@userid,0), coalesce(@username,@srvname,'SYSTEM'), 'insert',
    showreg(NEW.classes, NEW.classes_v), showreg(NEW.server, NEW.server_v), showreg(NEW.section, NEW.section_v),
    showreg(NEW.teststep, NEW.teststep_v), showreg(NEW.details, NEW.details_v),
    showreg(NEW.einheit, NEW.einheit_v),
    concat('datefrom=', NEW.datumvon,
           '\ndateto=', NEW.datumbis,
           if(NEW.weekdays = '0,1,2,3,4,5,6', '', concat('\nweekdays=', weekdaynames(NEW.weekdays))),
           if(NEW.mdays = '', '', concat('\nmdays=', getrange(NEW.mdays))),
           if(NEW.zeitvon = '00:00:00' AND NEW.zeitbis = '23:59:59', '',
              concat('\ntimefrom=', NEW.zeitvon, '\ntimeto=', coalesce(@suspensiontimeto,NEW.zeitbis))),
           '\nremark=', REPLACE(REPLACE(NEW.bemerkung, '\\', '\\\\'), '\n', '\\n'))
  from dual
  where NEW.nextdayID = 0;
end//


drop trigger if exists ueberwachungspausen_bd//
create trigger ueberwachungspausen_bd before delete on ueberwachungspausen
  for each row 
begin
  insert into changeprot
    (domainID, accessID, changedtable, tableID, userID, username, action,
     classes, server, section, teststep, details, unit, newvalues)
  select OLD.verfahrenID, OLD.accessID, 'ueberwachungspausen', OLD.ID,
    coalesce(@userid,0), coalesce(@username,@srvname,'SYSTEM'), 'delete',
    showreg(OLD.classes, OLD.classes_v), showreg(OLD.server, OLD.server_v), showreg(OLD.section, OLD.section_v),
    showreg(OLD.teststep, OLD.teststep_v), showreg(OLD.details, OLD.details_v),
    showreg(OLD.einheit, OLD.einheit_v),
    coalesce(if(OLD.bemerkung = @suspensionremark OR OLD.serversetID > 0, '', concat('remark=', REPLACE(REPLACE(@suspensionremark, '\\', '\\\\'), '\n', '\\n'))),'')
    from dual
    where OLD.nextdayID = 0;
end//

delimiter ;
